# The CORSMAL-Containers dataset

*Authors*:
* Alessio Xompero, a.xompero@qmul.ac.uk
* Ricardo Sanchez-Matilla
* Apostolos Modas
* Pascal Frossard
* Andrea Cavallaro

Created date: 2019/10/23

Version: 0.1

Resource type: Images

[CORSMAL-Containers website](https://cormsal.eecs.qmul.ac.uk/CORSMAL_Containers.html)
[ArXiv paper (coming soon)]()

## Citation/Reference
Xompero, A., Sanchez-Matilla, R., Modas, A., Frossard, P., Cavallaro, A., _Multi-view shape estimation of transparent containers_, Submitted to IEEE International Conference on Acoustic, Sound, and Signal Processing (ICASSP).

## Description
The CORSMAL-Containers dataset comprises 1,656 images from 23 liquid containers: 5 cups, 9 drinking glasses and 9 bottles, made of plastic, glass or paper, and with different degrees of transparency and arbitrary shapes.

The dataset is acquired with two Intel RealSense D435i cameras, located approximately 40cm from the object placed on the top of a table. The cameras are calibrated and localised with respect to a calibration board. The resulting images (1280x720 pixels) are RGB, depth and stereo infrared, with the RGB and depth images being spatially aligned.

Data acquisition is performed in two separate rooms with different lighting conditions and different backgrounds are obtained using two tablecloths in addition to a no-tabletop scenario. We employed an office room with natural lighting coming from a set of windows where the table is of size 160x80 cm and height 82 cm from the ground, and a studio-like room where there are no windows and the illumination is provided by either ceiling lights or additional portable lights and where the table is of size 60x60 cm and height 82 cm from the ground. We collected in total 207 configurations that are the combination of objects (23), backgrounds (3) and lighting conditions (3), resulting in 414 RGB images, 414 depth images and 828 IR images. We manually annotated the maximum width and height of each object with a digital caliper (0-150mm +- 0.01mm) and a measuring tape (0-10m +- 1mm).

## Data organisation

### Images
Each configuration consists of object id (idX), lighting condition (lX), and background (bX). For each configuration, we provide RGB, stereo IR, depth, and segmentation images for both cameras. 

For example:
* id0_l0_b0_c1_rgb.png
* id0_l0_b0_c1_depth.png
* id0_l0_b0_c1_ir1.png
* id0_l0_b0_c1_ir2.png
* id0_l0_b0_c2_rgb.png
* id0_l0_b0_c2_depth.png
* id0_l0_b0_c2_ir1.png
* id0_l0_b0_c2_ir2.png

### Calibration
_calibration.csv_ provides the intrinsic (focal lenght, fx and fy; principal point, px and py) and extrinsic (3x3 rotation matrix, and 3x1 translation vector) for each sensor and for each setup. 
Setup 1 contains the lighiting conditions: ceiling lights and artificial lights, while setup 2 contains the natural ligthing condition.
Intrinsic and extrinsic parameters are stored as single horizontally row vectors. 

The format of the file is:
*Columns
 fx,fy,cx,cy,R11,R12,R13,R21,R22,R23,R31,R32,R33,T1,T2,T3.
*Rows indicate the sensor
  1. camera 1 rgb
  2. camera 1 infrared 1
  3. camera 1 infrared 2
  4. camera 2 rgb
  5. camera 2 infrared 1
  6. camera 2 infrared 2 

Rows repeat for setup 1 and setup 2.

### Annotation
_data.csv_ contains the list of 23 objects (one object for each row). For each object, we annotate:
* Category (bottle, glass, cup)
* Instance (name of the object)
* Material (plastic, glass, paper)
* Shape (circular, non-circular)
* Transparency (0: opaque, 1: translucent, 2: transparent)
* Height (mm)
* Width (mm)

## Licence
This work is licensed under the Creative Commons Attribution-NonCommercial 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

